@@ -28,17 +28,17 @@
 #' library(omopgenerics)
 #'
 #' x <- tibble(
-#'  "result_id" = 1L,
-#'  "cdm_name" = "cprd",
-#'  "group_name" = "cohort_name",
-#'  "group_level" = "acetaminophen",
-#'  "strata_name" = "sex &&& age_group",
-#'  "strata_level" = c("male &&& <40", "male &&& >=40"),
-#'  "variable_name" = "number_subjects",
-#'  "variable_level" = NA_character_,
-#'  "estimate_name" = "count",
-#'  "estimate_type" = "integer",
-#'  "estimate_value" = c("5", "15"),
+#'   "result_id" = 1L,
+#'   "cdm_name" = "cprd",
+#'   "group_name" = "cohort_name",
+#'   "group_level" = "acetaminophen",
+#'   "strata_name" = "sex &&& age_group",
+#'   "strata_level" = c("male &&& <40", "male &&& >=40"),
+#'   "variable_name" = "number_subjects",
+#'   "variable_level" = NA_character_,
+#'   "estimate_name" = "count",
+#'   "estimate_type" = "integer",
+#'   "estimate_value" = c("5", "15"),
 #'   "additional_name" = "overall",
 #'   "additional_level" = "overall"
 #' ) |>
@@ -49,17 +49,17 @@
 #' summary(x)
 #'
 #' x <- tibble(
-#'  "result_id" = 1L,
-#'  "cdm_name" = "cprd",
-#'  "group_name" = "cohort_name",
-#'  "group_level" = "acetaminophen",
-#'  "strata_name" = "sex &&& age_group",
-#'  "strata_level" = c("male &&& <40", "male &&& >=40"),
-#'  "variable_name" = "number_subjects",
-#'  "variable_level" = NA_character_,
-#'  "estimate_name" = "count",
-#'  "estimate_type" = "integer",
-#'  "estimate_value" = c("5", "15"),
+#'   "result_id" = 1L,
+#'   "cdm_name" = "cprd",
+#'   "group_name" = "cohort_name",
+#'   "group_level" = "acetaminophen",
+#'   "strata_name" = "sex &&& age_group",
+#'   "strata_level" = c("male &&& <40", "male &&& >=40"),
+#'   "variable_name" = "number_subjects",
+#'   "variable_level" = NA_character_,
+#'   "estimate_name" = "count",
+#'   "estimate_type" = "integer",
+#'   "estimate_value" = c("5", "15"),
 #'   "additional_name" = "overall",
 #'   "additional_level" = "overall"
 #' ) |>
@@ -72,195 +72,325 @@
 #' summary(x)
 #'
 newSummarisedResult <- function(x, settings = attr(x, "settings")) {
-
   # inital input check
-  assertClass(x = x, class = "data.frame")
-  assertClass(x = settings, class = "data.frame", null = TRUE)
+  assertTable(x = x, class = "data.frame", columns = resultColumns("summarised_result"), allowExtraColumns = TRUE)
+  assertTable(x = settings, class = "data.frame", null = TRUE, columns = "result_id", allowExtraColumns = TRUE)
 
   # constructor
   x <- constructSummarisedResult(x, settings)
 
   # validate
-  x <- validateSummariseResult(x)
+  x <- validateSummarisedResult(x)
 
   return(x)
 }
 
-constructSummarisedResult <- function(x, set, call = parent.frame()) {
+constructSummarisedResult <- function(x, settings) {
+  x <- dplyr::as_tibble(x) |>
+    dplyr::mutate(result_id = as.integer(.data$result_id))
+
+  settings <- createSettings(x, settings) |>
+    dplyr::arrange(.data$result_id)
+
   x <- x |>
-    dplyr::as_tibble()
+    dplyr::select(dplyr::all_of(resultColumns(table = "summarised_result"))) |>
+    dplyr::filter(.data$variable_name != "settings") |>
+    dplyr::arrange(.data$result_id)
 
-  if (!is.null(set)) {
-    set <- set |> dplyr::as_tibble()
-    if (!"result_id" %in% colnames(set)) {
-      cli::cli_abort("result_id must be a column of settings argument", call = call)
-    }
-  }
+  structure(.Data = x, settings = settings) |>
+    addClass(c("summarised_result", "omop_result"))
+}
+validateSummarisedResult <- function(x,
+                                     call = parent.frame()) {
+  # settings
+  validateResultSettings(attr(x, "settings"), call = call)
 
-  settingsCols <- colnames(x)[
-    !colnames(x) %in% resultColumns(table = "summarised_result")
-  ]
-  if (!"result_id" %in% colnames(x)) {
-    x <- x |>
-      dplyr::group_by(dplyr::across(dplyr::all_of(settingsCols))) |>
-      dplyr::mutate("result_id" = as.integer(dplyr::cur_group_id())) |>
-      dplyr::ungroup()
-    cli::cli_alert_warning("`result_id` column is missing, please add it as it is a compulsory column.")
-  }
-  x <- checkColumns(x = x, resultName = "summarised_result", call = call)
-  if (length(settingsCols) > 0) {
-    cli::cli_alert_warning("The following variables: {paste0(settingsCols, collapse = ', ')}; were added to `settings`")
-    set <- set |>
-      joinSet(
-        x |>
-          dplyr::select(dplyr::all_of(c("result_id", settingsCols))) |>
-          dplyr::distinct()
-      )
-  }
+  # sr
+  validateSummarisedResultTable(x, call = call)
+}
+createSettings <- function(x, settings) {
+  set <- list()
 
-  x <- x |> dplyr::select(!dplyr::all_of(settingsCols))
-  extraSets <- x |>
+  # provided settings
+  set$provided <- dplyr::as_tibble(settings)
+
+  # present in result
+  set$present <- x |>
+    dplyr::select("result_id") |>
+    dplyr::distinct()
+
+  # long settings
+  notCharacter <- character()
+  setLong <- x |>
     dplyr::filter(.data$variable_name == "settings") |>
     dplyr::select(
       "result_id", "estimate_name", "estimate_type", "estimate_value"
     )
-  if (nrow(extraSets) > 0) {
-    errorRows <- extraSets |>
-      dplyr::group_by(.data$result_id, .data$estimate_name) |>
-      dplyr::tally(name = "n") |>
-      dplyr::filter(.data$n > 1) |>
-      dplyr::pull("estimate_name") |>
-      unique()
-    if (length(errorRows) > 0) {
-      cli::cli_alert_warning("The following settings have duplicate values for same result_id: {paste0(errorRows, collapse = ', ')}.")
+  if (nrow(setLong) > 0) {
+    if (any(unique(setLong$estimate_type) != "character")) {
+      notCharacter <- setLong$estimate_name[setLong$estimate_type != "character"]
     }
-    extraSets <- extraSets |>
+    set$long <- setLong |>
+      dplyr::select(!"estimate_type") |>
+      dplyr::distinct() |>
       tidyr::pivot_wider(
-        names_from = c("estimate_type", "estimate_name"),
-        values_from = "estimate_value"
-      ) |>
-      dplyr::mutate(
-        dplyr::across(
-          .cols = dplyr::starts_with("numeric|proportion|percentage"),
-          .fns = as.numeric
-        ),
-        dplyr::across(
-          .cols = dplyr::starts_with("integer"),
-          .fns = as.integer
-        ),
-        dplyr::across(
-          .cols = dplyr::starts_with("date"),
-          .fns = as.Date
-        ),
-        dplyr::across(
-          .cols = dplyr::starts_with("logical"),
-          .fns = as.logical
-        )
-      ) |>
-      dplyr::rename_with(.fn = ~ sub("^[^_]*_", "", .x), .cols = !"result_id")
-    set <- set |> joinSet(extraSets)
-    x <- x |> dplyr::filter(.data$variable_name != "settings")
+        names_from = "estimate_name", values_from = "estimate_value"
+      )
   }
 
-  if (is.null(set)) {
-    set <- x |> dplyr::select("result_id") |> dplyr::distinct()
+  # extra columns
+  cols <- colnames(x)
+  cols <- cols[!cols %in% resultColumns("summarised_result")]
+  if (length(cols) > 0) {
+    cli::cli_inform("{.var {cols}} moved to settings.")
+    set$extra_columns <- x |>
+      dplyr::select("result_id", dplyr::all_of(cols)) |>
+      dplyr::distinct()
   }
 
-  requiredSettingsColumns <- resultColumns(table = "settings")
-  notPresent <- requiredSettingsColumns[
-    !requiredSettingsColumns %in% colnames(set)]
-  if (length(notPresent) > 0) {
-    '{.var {notPresent}} {?is/are} not provided will be populated as "" in settings' |>
-      cli::cli_warn()
-    for (col in notPresent) {
+  # merge settings
+  set <- set |>
+    purrr::compact() |>
+    purrr::map(\(x) dplyr::mutate(x, result_id = as.integer(.data$result_id))) |>
+    purrr::reduce(dplyr::full_join, by = "result_id")
+
+  # missing settings
+  compulsory <- c("result_type", "package_name", "package_version")
+  colsMissing <- compulsory[!compulsory %in% colnames(set)]
+  if (length(colsMissing) > 0) {
+    cli::cli_inform("{.var {colsMissing}} added to {.pkg settings}.")
+    for (col in colsMissing) {
       set <- set |>
         dplyr::mutate(!!col := "")
     }
   }
+  set <- set |>
+    dplyr::mutate(dplyr::across(
+      .cols = dplyr::all_of(compulsory), \(x) dplyr::coalesce(x, "")
+    ))
 
-  x <- structure(
-    .Data = x,
-    class = unique(c("summarised_result", "omop_result", class(x))),
-    settings = set |>
-      dplyr::mutate("result_id" = as.integer(.data$result_id)) |>
-      dplyr::relocate("result_id") |>
-      dplyr::arrange(.data$result_id)
+  # group, strata and additional
+  set <- set |>
+    addLabels(x, "group") |>
+    addLabels(x, "strata") |>
+    addLabels(x, "additional")
+
+  # all settings must be character
+  types <- variableTypes(set)
+  notCharacter <- c(
+    notCharacter,
+    types$variable_name[types$variable_type != "character" & types$variable_name != "result_id"]
   )
-
-  return(x)
-}
-joinSet <- function(set, addset) {
-  if (is.null(set)) {
-    set <- addset
-  } else {
-    set <- addset |> dplyr::full_join(set, by = "result_id")
+  if (length(notCharacter) > 0) {
+    cli::cli_inform("{.var {notCharacter}} casted to character.")
+    set <- set |>
+      dplyr::mutate(dplyr::across(
+        dplyr::all_of(notCharacter), \(x) as.character(x)
+      ))
   }
+
+  # min_cell_count
+  if (!"min_cell_count" %in% colnames(set)) {
+    set <- set |>
+      dplyr::mutate(min_cell_count = "0")
+  } else {
+    set <- set |>
+      dplyr::mutate(
+        min_cell_count = dplyr::coalesce(.data$min_cell_count, "0"),
+        min_cell_count = dplyr::if_else(
+          .data$min_cell_count == "1", "0", .data$min_cell_count
+        )
+      )
+  }
+
+  # remove NA
+  colsRemove <- set |>
+    purrr::map(\(x) {
+      if (all(is.na(x))) {
+        x
+      } else {
+        NULL
+      }
+    }) |>
+    purrr::compact() |>
+    names()
+  if (length(colsRemove) > 0) {
+    cli::cli_inform("{.var {colsRemove}} eliminated from settings as all elements are NA.")
+    set <- set |>
+      dplyr::select(!dplyr::all_of(colsRemove))
+  }
+
+  # order variables
+  initialCols <- c(
+    "result_id", "result_type", "package_name", "package_version", "group",
+    "strata", "additional", "min_cell_count"
+  )
+  otherCols <- sort(colnames(set)[!colnames(set) %in% initialCols])
+  set <- set |>
+    dplyr::select(dplyr::all_of(c(initialCols, otherCols)))
+
   return(set)
 }
-validateSummariseResult <- function(x) {
-  if (!"result_id" %in% colnames(x)) {
-    x <- x |> dplyr::mutate("result_id" = as.integer(1))
-    warnResult <- TRUE
-  } else {
-    warnResult <- FALSE
+addLabels <- function(set, x, prefix) {
+  if (!prefix %in% colnames(set)) {
+    if (nrow(x) == 0) {
+      set <- set |>
+        dplyr::mutate(!!prefix := "")
+    } else {
+      set <- set |>
+        dplyr::left_join(
+          x |>
+            dplyr::group_by(.data$result_id) |>
+            dplyr::group_split() |>
+            purrr::map(\(x) {
+              resId <- x$result_id[1]
+              lab <- x |>
+                dplyr::select(dplyr::all_of(paste0(prefix, "_name"))) |>
+                dplyr::distinct() |>
+                dplyr::pull() |>
+                stringr::str_split(pattern = " &&& ") |>
+                unlist() |>
+                unique()
+              lab <- paste0(lab[lab != "overall"], collapse = " &&& ")
+              dplyr::tibble(result_id = resId, !!prefix := lab)
+            }) |>
+            dplyr::bind_rows(),
+          by = "result_id"
+        )
+    }
+  }
+  set |>
+    dplyr::mutate(!!prefix := dplyr::coalesce(.data[[prefix]], ""))
+}
+validateResultSettings <- function(set, call) {
+  if (is.null(set)) {
+    "{.cls summarised_result} object does not have settings attribute." |>
+      cli::cli_abort(call = call)
+  }
+  if (!"result_id" %in% colnames(set)) {
+    "{.var result_id} must be part of settings attribute." |>
+      cli::cli_abort(call = call)
+  }
+  types <- variableTypes(set)
+  if (types$variable_type[types$variable_name == "result_id"] != "integer") {
+    "{.var result_id} must be {.cls integer} in settings attribute." |>
+      cli::cli_abort(call = call)
+  }
+  types <- types |>
+    dplyr::filter(.data$variable_name != "result_id")
+  notCharacter <- types$variable_name[types$variable_type != "character"]
+  if (length(notCharacter) > 0) {
+    "{.var {notCharacter}} must be {.cls character} in settings attribute." |>
+      cli::cli_abort(call = call)
+  }
+  if (length(set$result_id) != length(unique(set$result_id))) {
+    "{.var result_id} must be unique in settings attribute." |>
+      cli::cli_abort(call = call)
+  }
+  if (nrow(set) != nrow(dplyr::distinct(dplyr::select(set, !"result_id")))) {
+    "Each {.var result_id} must be unique and contain a unique set of {.pkg settings}." |>
+      cli::cli_abort(call = call)
+  }
+  # tidy names
+  tidyGroup <- extractColumns(set, "group")
+  tidyStrata <- extractColumns(set, "strata")
+  tidyAdditional <- extractColumns(set, "additional")
+  reportOverlap(tidyGroup, tidyStrata, "group", "strata", call)
+  reportOverlap(tidyGroup, tidyAdditional, "group", "additional", call)
+  reportOverlap(tidyStrata, tidyAdditional, "strata", "additional", call)
+
+  invisible()
+}
+getLabels <- function(x) {
+  res <- stringr::str_split(string = x, pattern = " &&& ") |>
+    purrr::flatten_chr()
+  res[!res %in% c("", "overall")]
+}
+extractColumns <- function(x, col) {
+  x[[col]] |>
+    as.list() |>
+    rlang::set_names(as.character(x$result_id)) |>
+    purrr::map(\(x) unique(getLabels(x)))
+}
+reportOverlap <- function(tidy1, tidy2, group1, group2, call) {
+  x <- purrr::map2(tidy1, tidy2, intersect) |>
+    purrr::compact()
+  if (length(x) == 0) {
+    return(invisible())
+  }
+  message <- x |>
+    purrr::imap_chr(\(x, nm) {
+      paste0(
+        "In result_id = ", nm, ": `", paste0(x, collapse = "`, `"),
+        "` present in both {.pkg ", group1, "} and {.pkg ", group2, "}."
+      )
+    }) |>
+    unname()
+  cli::cli_abort(message = message, call = call)
+}
+validateSummarisedResultTable <- function(x,
+                                          duplicates = TRUE,
+                                          pairs = TRUE,
+                                          duplicateEstimates = TRUE,
+                                          suppressPossibility = TRUE,
+                                          call) {
+  # all columns
+  columns <- resultColumns(table = "summarised_result")
+  notPresent <- columns[!columns %in% colnames(x)]
+  if (length(notPresent) > 0) {
+    "{.var {notPresent}} not present in {.cls summarised_result} object." |>
+      cli::cli_abort(call = call)
   }
 
-  # compulsory columns
-  x <- checkColumns(x = x, "summarised_result")
-  if (warnResult) {
-    cli::cli_warn(c(
-      "!" = "`result_id` column is missing, please add it as it is a compulsory
-      column."
-    ))
-  }
-
-  # all columns should be character
+  # correct type
   x <- checkColumnsFormat(x = x, "summarised_result")
 
   # Cannot contain NA columns
   checkNA(x = x, "summarised_result")
 
-  # duplicated entries with same value
-  nr <- nrow(x)
-  x <- x |> dplyr::distinct()
-  eliminated <- nr - nrow(x)
-  if (eliminated > 0) {
-    cli::cli_inform(c("!" = "{eliminated} duplicated row{?s} eliminated."))
+  # estimate type
+  estimateType <- unique(x$estimate_type)
+  notValidEstimateTypes <- estimateType[!estimateType %in% estimateTypeChoices()]
+  if (length(notValidEstimateTypes) > 0) {
+    "{.var {notValidEstimateTypes}} {?is/are} not valid estimate_type values." |>
+      cli::cli_abort(call = call)
+  }
+
+  # all ids in result must be in settings
+  idsResult <- unique(x$result_id)
+  idsSettings <- unique(attr(x, "settings")$result_id)
+  notPresent <- idsResult[!idsResult %in% idsSettings]
+  if (length(notPresent) > 0) {
+    cli::cli_abort("result_id: {.var {notPresent}} not present in {.pkg settings} but present in data.")
+  }
+
+  # duplicates
+  if (duplicates) {
+    nr <- nrow(x)
+    x <- x |>
+      dplyr::distinct()
+    eliminated <- nr - nrow(x)
+    if (eliminated > 0) {
+      cli::cli_inform(c("!" = "{eliminated} duplicated row{?s} eliminated."))
+    }
   }
 
   # columPairs
-  validateNameLevel(x = x, prefix = "group", validation = "warning")
-  validateNameLevel(x = x, prefix = "strata", validation = "warning")
-  validateNameLevel(x = x, prefix = "additional", validation = "warning")
-
-  # estimate_type
-  checkColumnContent(
-    x = x, col = "estimate_type", content = estimateTypeChoices()
-  )
-
-  # settings
-  sets <- settings(x)
-  idSummary <- x |>
-    dplyr::select("result_id") |>
-    dplyr::distinct() |>
-    dplyr::pull()
-  idSettings <- sets |> dplyr::pull("result_id")
-  if (length(idSettings) != length(unique(idSettings))) {
-    cli::cli_abort("ids are not unique in settings")
-  }
-  notPresent <- idSummary[!idSummary %in% idSettings]
-  if (length(notPresent) > 0) {
-    cli::cli_abort("There are ids present in the summary that do not have settings: {paste0(notPresent, collapse = ', ')}")
+  if (pairs) {
+    validateNameLevel(x = x, prefix = "group", validation = "warning")
+    validateNameLevel(x = x, prefix = "strata", validation = "warning")
+    validateNameLevel(x = x, prefix = "additional", validation = "warning")
   }
 
-  # validate groupCount
-  checkGroupCount(x)
+  # no duplicated estimates
+  if (duplicateEstimates) {
+    checkDuplicated(x, validation = "error")
+  }
 
-  # validate duplicates
-  checkDuplicated(x, validation = "error")
-
-  # validate tidyNames
-  validateTidyNames(x)
+  # suppress availability
+  if (suppressPossibility) {
+    checkGroupCount(x)
+  }
 
   return(x)
 }
@@ -323,9 +453,9 @@ checkColumnsFormat <- function(x, resultName) {
   invisible(x)
 }
 checkGroupCount <- function(x, validation = "error", call = parent.frame()) {
-  groupping <- c(
+  grouping <- c(
     "result_id", "cdm_name", "group_name", "group_level", "strata_name",
-    "strata_level"
+    "strata_level", "additional_name", "additional_level"
   )
   obsLabels <- x |>
     dplyr::pull("variable_name") |>
@@ -342,14 +472,14 @@ checkGroupCount <- function(x, validation = "error", call = parent.frame()) {
         dplyr::filter(
           .data$variable_name %in% ol & grepl("count", .data$estimate_name)
         ) |>
-        dplyr::select(dplyr::all_of(c(groupping, "variable_name"))) |>
-        dplyr::group_by(dplyr::across(dplyr::all_of(groupping))) |>
+        dplyr::select(dplyr::all_of(c(grouping, "variable_name"))) |>
+        dplyr::group_by(dplyr::across(dplyr::all_of(grouping))) |>
         dplyr::filter(dplyr::n() > 1) |>
         dplyr::group_split() |>
         as.list()
       for (k in seq_along(xx)) {
         if (n < 5) {
-          res <- c(res, "*" = glue::glue("{nrow(xx[[k]])} '{gcount}' in variable_name for: {getGroupping(xx[[k]])}."))
+          res <- c(res, "*" = glue::glue("{nrow(xx[[k]])} '{gcount}' in variable_name for: {getGrouping(xx[[k]])}."))
           n <- n + 1
         }
       }
@@ -357,7 +487,7 @@ checkGroupCount <- function(x, validation = "error", call = parent.frame()) {
   }
   if (length(res) > 0) {
     res <- c(
-      "Each groupping (unique combination of: {groupping}) can not contain repeated group identifiers ({groupCount}).",
+      "Each grouping (unique combination of: {grouping}) can not contain repeated group identifiers ({groupCount}).",
       "First {n} combination{?s}:",
       res
     )
@@ -365,7 +495,7 @@ checkGroupCount <- function(x, validation = "error", call = parent.frame()) {
   }
   return(invisible(NULL))
 }
-getGroupping <- function(x) {
+getGrouping <- function(x) {
   x <- x |>
     dplyr::select(-dplyr::any_of("variable_name")) |>
     dplyr::distinct() |>
@@ -443,7 +573,9 @@ validateNameLevel <- function(x,
   }
 
   # check case
-  nameCase <- distinctPairs[["name_elements"]] |> unlist() |> unique()
+  nameCase <- distinctPairs[["name_elements"]] |>
+    unlist() |>
+    unique()
   notSnake <- nameCase[!isCase(nameCase, "snake")]
   if (length(notSnake) > 0) {
     "{length(notSnake)} element{?s} in {nameColumn} {?is/are} not snake_case." |>
@@ -453,9 +585,10 @@ validateNameLevel <- function(x,
   return(invisible(x))
 }
 isCase <- function(x, case) {
-  if (length(x) == 0) return(logical())
-  flag <- switch(
-    case,
+  if (length(x) == 0) {
+    return(logical())
+  }
+  flag <- switch(case,
     "snake" = isSnakeCase(x),
     "sentence" = isSentenceCase(x),
     "NA" = rep(TRUE, length(x)),
@@ -514,8 +647,7 @@ checkDuplicated <- function(x, validation, call = parent.frame()) {
   return(invisible(TRUE))
 }
 giveType <- function(x, type) {
-  switch(
-    type,
+  switch(type,
     "integer" = as.integer(x),
     "double" = as.double(x),
     "character" = as.character(x),
@@ -551,8 +683,8 @@ validateTidyNames <- function(result, call = parent.frame()) {
   # compare each pair
   len <- length(cols)
   nms <- names(cols)
-  for (k in 1:(len -1)) {
-    for (i in (k+1):len) {
+  for (k in 1:(len - 1)) {
+    for (i in (k + 1):len) {
       both <- intersect(cols[[k]], cols[[i]])
       if (length(both) > 0) {
         "{.var {both}} {?is/are} present in both '{nms[k]}' and '{nms[i]}'. This will be an error in the next release." |>
@@ -640,50 +772,6 @@ emptySummarisedResult <- function(settings = NULL) {
     newSummarisedResult(settings = settings)
 }
 
-.validateSummarisedResult <- function(result,
-                                      checkNameLevelPairs,
-                                      checkTidyColumns,
-                                      checkDuplicated,
-                                      call = parent.frame()) {
-  # basic checks
-  # class
-  if (!inherits(result, "summarised_result")) {
-    "result is not a {.cls summarised_result} object." |>
-      report(validation = "error", call = call)
-  }
-
-  # compulsory columns
-  result <- checkColumns(result, "summarised_result", call = call)
-
-  # columns format
-  result <- checkColumnsFormat(result, "summarised_result")
-
-  # Cannot contain NA columns
-  checkNA(result, "summarised_result")
-
-  # duplicated entries with same value
-  nr <- nrow(x)
-  x <- x |> dplyr::distinct()
-  eliminated <- nr - nrow(x)
-  if (eliminated > 0) {
-    "{eliminated} duplicated row{?s} eliminated." |>
-      report(validation = "message", call = call)
-  }
-
-  # checkNameLevelPairs
-  if (!is.null(checkNameLevelPairs)) {
-    for (prefix in c("group", "strata", "additional")) {
-      validateNameLevel(result, prefix = prefix, validation = checkNameLevelPairs)
-    }
-  }
-
-  # checkTidyColumns
-
-  # checkDuplicated
-
-
-  return(result)
-}
 report <- function(message,
                    validation, # error/warning/inform
                    call = parent.frame(), # where error is reported
