@@ -1,6 +1,4 @@
-
-test_that("you can create empty objects",{
-
+test_that("you can create empty objects", {
   # cdm_reference
   expect_error(emptyCdmReference())
   expect_no_error(cdm <- emptyCdmReference(cdmName = "test"))
@@ -52,14 +50,21 @@ test_that("you can create empty objects",{
   # summarised result
   expect_no_error(x <- emptySummarisedResult())
   expect_true(inherits(x, "summarised_result"))
-  expect_identical(settings(x), dplyr::tibble("result_id" = integer(),
-                                              "result_type" = character(),
-                                              "package_name" = character(),
-                                              "package_version" = character()))
+  expect_identical(
+    settings(x),
+    dplyr::tibble(
+      "result_id" = integer(), "result_type" = character(),
+      "package_name" = character(), "package_version" = character(),
+      "group" = character(), "strata" = character(), "additional" = character(),
+      "min_cell_count" = character()
+    )
+  )
 
   set <- dplyr::tibble("result_id" = 1L, "my_setting" = TRUE)
   expect_no_error(x <- emptySummarisedResult(settings = set))
   expect_true(inherits(x, "summarised_result"))
-  expect_identical(settings(x) |> dplyr::select("result_id","my_setting"), set)
-
+  expect_identical(
+    settings(x) |> dplyr::select("result_id", "my_setting"),
+    set |> dplyr::mutate(my_setting = as.character(.data$my_setting))
+  )
 })
