@@ -1,4 +1,3 @@
-
 test_that("test validateNameArgument", {
   expect_error(validateNameArgument(name = 1))
   expect_error(validateNameArgument(name = c("sda", "asdfsa")))
@@ -13,16 +12,92 @@ test_that("test validateNameArgument", {
 })
 
 test_that("test validateCohortIdArgument", {
-  cohort <- 1
-  class(cohort) <- c("cohort_table", "cdm_table")
+  # toy cohort
+  cohort <- dplyr::tibble(
+    cohort_definition_id = 1:4L, subject_id = 1L, cohort_start_date = Sys.Date(),
+    cohort_end_date = Sys.Date()
+  ) |>
+    addClass(c("cohort_table", "cdm_table"))
   attr(cohort, "cohort_set") <- dplyr::tibble(
-    "cohort_definition_id" = c(2, 4), "cohort_name" = c("a", "b")
+    "cohort_definition_id" = c(1L, 2L, 3L, 4L),
+    "cohort_name" = c("cohort_a", "acetaminophen", "paracetamol", "cohort_ol")
   )
-  expect_error(validateCohortIdArgument("adsfd", cohort))
+
+  # numeric behavior
   expect_identical(validateCohortIdArgument(2, cohort), 2L)
   expect_identical(validateCohortIdArgument(c(2, 4), cohort), c(2L, 4L))
   expect_identical(validateCohortIdArgument(c(4L, 2L), cohort), c(4L, 2L))
-  expect_error(validateCohortIdArgument(1, cohort))
+  expect_error(validateCohortIdArgument(5, cohort))
+  expect_warning(expect_identical(
+    validateCohortIdArgument(c(2, 8), cohort, validation = "warning"),
+    2L
+  ))
+  expect_warning(expect_warning(expect_identical(
+    validateCohortIdArgument(5, cohort, validation = "warning"),
+    integer()
+  )))
+
+  # character behavior
+  expect_identical(validateCohortIdArgument("acetaminophen", cohort), 2L)
+  expect_identical(
+    validateCohortIdArgument(c("acetaminophen", "paracetamol"), cohort),
+    c(2L, 3L)
+  )
+  expect_identical(
+    validateCohortIdArgument(c("paracetamol", "acetaminophen"), cohort),
+    c(3L, 2L)
+  )
+  expect_error(validateCohortIdArgument(c("not_present"), cohort))
+  expect_warning(expect_identical(
+    validateCohortIdArgument(
+      c("paracetamol", "not_present"), cohort,
+      validation = "warning"
+    ),
+    3L
+  ))
+  expect_warning(expect_warning(expect_identical(
+    validateCohortIdArgument(c("not_present"), cohort, validation = "warning"),
+    integer()
+  )))
+
+  # tidyselect behavior
+  expect_identical(
+    validateCohortIdArgument(dplyr::starts_with("cohort_"), cohort),
+    c(1L, 4L)
+  )
+  expect_identical(
+    validateCohortIdArgument(dplyr::ends_with("ol"), cohort),
+    c(3L, 4L)
+  )
+  expect_identical(
+    validateCohortIdArgument(dplyr::everything(), cohort),
+    c(1L, 2L, 3L, 4L)
+  )
+  expect_error(
+    validateCohortIdArgument(dplyr::any_of(c("sdfghjk", "dfg")), cohort)
+  )
+  expect_warning(expect_identical(
+    validateCohortIdArgument(
+      dplyr::any_of(c("sdfghjk", "dfg")), cohort,
+      validation = "warning"
+    ),
+    integer()
+  ))
+
+  # NULL
+  expect_identical(validateCohortIdArgument(NULL, cohort), c(1L, 2L, 3L, 4L))
+
+  # error if anything else is provided
+  expect_error(validateCohortIdArgument(list(), cohort))
+  expect_error(validateCohortIdArgument(list(), cohort, validation = "warning"))
+
+  # check in external function
+  filterCohort <- function(x, id) {
+    id <- validateCohortIdArgument({{ id }}, x)
+    x |>
+      dplyr::filter(.data$cohort_definition_id %in% .env$id)
+  }
+  expect_no_error(filterCohort(cohort, dplyr::starts_with("cohort")))
 })
 
 test_that("test validateWindowArgument", {
@@ -41,7 +116,7 @@ test_that("test validateWindowArgument", {
   window <- list(c(Inf, Inf))
   expect_error(validateWindowArgument(window))
 
-  #window name check
+  # window name check
   window <- list(c(-1, 1))
 
   window <- window |> validateWindowArgument(snakeCase = FALSE)
@@ -58,45 +133,50 @@ test_that("test validateWindowArgument", {
   window <- list("window" = c(-1, 1))
   window <- window |> validateWindowArgument(snakeCase = TRUE)
   expect_true(names(window) == "window")
-
 })
 
 test_that("test validateAgeGroup", {
-  #test list
+  # test list
   expect_error(validateAgeGroupArgument(c("1", "18")))
-  ageGroup = list(c(0, 18))
+  ageGroup <- list(c(0, 18))
   expect_no_error(validateAgeGroupArgument(ageGroup))
 
-  #test name
-  ageGroup = validateAgeGroupArgument(ageGroup)
+  # test name
+  ageGroup <- validateAgeGroupArgument(ageGroup)
   expect_true(names(ageGroup) == "age_group")
 
   # name multiple group
-  ageGroup = list(list(c(0, 19)), list(c(0, 18)))
-  ageGroup = validateAgeGroupArgument(ageGroup)
+  ageGroup <- list(list(c(0, 19)), list(c(0, 18)))
+  ageGroup <- validateAgeGroupArgument(ageGroup)
   expect_true(all(names(ageGroup) == c("age_group_1", "age_group_2")))
 
-  #test overlap
-  ageGroup = list(c(0, 18), c(16, 20))
+  # test overlap
+  ageGroup <- list(c(0, 18), c(16, 20))
   expect_error(validateAgeGroupArgument(ageGroup, overlap = FALSE))
   expect_no_error(validateAgeGroupArgument(ageGroup, overlap = TRUE))
 
-  #test order
-  ageGroup = list(c(19, 18), c(21, 20))
+  # test order
+  ageGroup <- list(c(19, 18), c(21, 20))
   expect_error(validateAgeGroupArgument(ageGroup, overlap = FALSE))
 
   # test multiple age group
-  ageGroup = list(list(c(0, 19)), list(c(0, 18)))
+  ageGroup <- list(list(c(0, 19)), list(c(0, 18)))
   expect_error(validateAgeGroupArgument(
-    ageGroup, overlap = FALSE, multipleAgeGroup = FALSE))
+    ageGroup,
+    overlap = FALSE, multipleAgeGroup = FALSE
+  ))
   expect_no_error(validateAgeGroupArgument(
-    ageGroup, overlap = FALSE, multipleAgeGroup = TRUE))
+    ageGroup,
+    overlap = FALSE, multipleAgeGroup = TRUE
+  ))
 
   # null age group
   expect_no_error(validateAgeGroupArgument(
-    ageGroup = NULL, overlap = FALSE, multipleAgeGroup = FALSE))
+    ageGroup = NULL, overlap = FALSE, multipleAgeGroup = FALSE
+  ))
   expect_error(validateAgeGroupArgument(
-    ageGroup = NULL, overlap = FALSE, null = FALSE, multipleAgeGroup = FALSE))
+    ageGroup = NULL, overlap = FALSE, null = FALSE, multipleAgeGroup = FALSE
+  ))
 
   # correct naming
   x <- list(0, c(1, 19), c(20, 39), c(40, 59), c(60, 79), c(80, Inf)) |>
@@ -115,7 +195,6 @@ test_that("test validateAgeGroup", {
 })
 
 test_that("test validateCdmArgument", {
-
   cdm_object <- 1
   class(cdm_object) <- c("cdm_reference")
   expect_no_error(
@@ -139,7 +218,8 @@ test_that("test validateCdmArgument", {
       observation_period_start_date = as.Date("2000-01-01"),
       observation_period_end_date = as.Date("2023-12-31"),
       period_type_concept_id = 0L
-    ))
+    )
+  )
 
   class(cdm_object) <- c("cdm_reference")
 
@@ -153,11 +233,12 @@ test_that("test validateCdmArgument", {
 
   cdm_object <- list(
     "observation_period" = dplyr::tibble(
-      observation_period_id = c(1L,1L), person_id = c(1L,1L),
-      observation_period_start_date = c(as.Date("2000-01-01"),as.Date("2000-01-01")),
-      observation_period_end_date = c(as.Date("2023-12-31"),as.Date("2023-01-01")),
-      period_type_concept_id = c(0L,0L)
-    ))
+      observation_period_id = c(1L, 1L), person_id = c(1L, 1L),
+      observation_period_start_date = c(as.Date("2000-01-01"), as.Date("2000-01-01")),
+      observation_period_end_date = c(as.Date("2023-12-31"), as.Date("2023-01-01")),
+      period_type_concept_id = c(0L, 0L)
+    )
+  )
   class(cdm_object) <- c("cdm_reference")
 
   expect_error(
@@ -179,11 +260,12 @@ test_that("test validateCdmArgument", {
   # implausible starting observation date
   cdm_object <- list(
     "observation_period" = dplyr::tibble(
-      observation_period_id = c(1L,1L), person_id = c(1L,1L),
-      observation_period_start_date = c(as.Date("1700-01-01"),as.Date("2000-01-01")),
-      observation_period_end_date = c(as.Date("2000-01-01"),as.Date("2023-01-01")),
-      period_type_concept_id = c(0L,0L)
-    ))
+      observation_period_id = c(1L, 1L), person_id = c(1L, 1L),
+      observation_period_start_date = c(as.Date("1700-01-01"), as.Date("2000-01-01")),
+      observation_period_end_date = c(as.Date("2000-01-01"), as.Date("2023-01-01")),
+      period_type_concept_id = c(0L, 0L)
+    )
+  )
   class(cdm_object) <- c("cdm_reference")
   expect_warning(
     validateCdmArgument(
@@ -201,11 +283,12 @@ test_that("test validateCdmArgument", {
   # implausible ending observation date - currently a warning instead of e
   cdm_object <- list(
     "observation_period" = dplyr::tibble(
-      observation_period_id = c(1L,1L), person_id = c(1L,1L),
-      observation_period_start_date = c(as.Date("2000-01-01"),as.Date("2000-01-02")),
-      observation_period_end_date = c(as.Date("2000-01-01"),as.Date("2100-01-01")),
-      period_type_concept_id = c(0L,0L)
-    ))
+      observation_period_id = c(1L, 1L), person_id = c(1L, 1L),
+      observation_period_start_date = c(as.Date("2000-01-01"), as.Date("2000-01-02")),
+      observation_period_end_date = c(as.Date("2000-01-01"), as.Date("2100-01-01")),
+      period_type_concept_id = c(0L, 0L)
+    )
+  )
   class(cdm_object) <- c("cdm_reference")
   expect_warning(
     validateCdmArgument(
@@ -229,28 +312,29 @@ test_that("test validateCdmArgument", {
       checkStartBeforeEndObservation = TRUE,
       checkPlausibleObservationDates = TRUE
     )
-    )
+  )
 
   # warnings if clinical table contain person id not in person  table
 
   cdm_object <- list(
     "observation_period" = dplyr::tibble(
-      observation_period_id = c(1L,1L), person_id = c(1L,1L),
-      observation_period_start_date = c(as.Date("2000-01-01"),as.Date("2000-01-02")),
-      observation_period_end_date = c(as.Date("2000-01-01"),as.Date("2100-01-01")),
-      period_type_concept_id = c(0L,0L)
+      observation_period_id = c(1L, 1L), person_id = c(1L, 1L),
+      observation_period_start_date = c(as.Date("2000-01-01"), as.Date("2000-01-02")),
+      observation_period_end_date = c(as.Date("2000-01-01"), as.Date("2100-01-01")),
+      period_type_concept_id = c(0L, 0L)
     ),
     "person" = dplyr::tibble(
-      person_id = c(1L,1L),
-      gender_concept_id = c(8507L,8507L),
-      year_of_birth = c(1991L,1992L)
+      person_id = c(1L, 1L),
+      gender_concept_id = c(8507L, 8507L),
+      year_of_birth = c(1991L, 1992L)
     ),
     "condition_occurrence" = dplyr::tibble(
-      condition_occurrence_id = c(1L,2L),
-      person_id = c(8507L,8507L),
-      condition_start_date =  c(as.Date("2000-01-01"),as.Date("2000-01-02")),
-      condition_end_date = c(as.Date("2000-01-01"),as.Date("2100-01-01"))
-    ))
+      condition_occurrence_id = c(1L, 2L),
+      person_id = c(8507L, 8507L),
+      condition_start_date = c(as.Date("2000-01-01"), as.Date("2000-01-02")),
+      condition_end_date = c(as.Date("2000-01-01"), as.Date("2100-01-01"))
+    )
+  )
 
   class(cdm_object) <- c("cdm_reference")
 
@@ -267,11 +351,9 @@ test_that("test validateCdmArgument", {
       checkPerson = TRUE
     )
   )
-
 })
 
 test_that("test validateResults", {
-
   x <- dplyr::tibble(
     "result_id" = as.integer(1),
     "cdm_name" = "cprd",
@@ -294,12 +376,11 @@ test_that("test validateResults", {
 
 
   expect_no_error(x |>
-                    newSummarisedResult() |>
-                    validateResultArgument())
-
+    newSummarisedResult() |>
+    validateResultArgument())
 })
 
-test_that("test isResultSuppressed",{
+test_that("test isResultSuppressed", {
   obj <- dplyr::tibble(
     "result_id" = as.integer(1),
     "cdm_name" = "mock",
@@ -335,5 +416,4 @@ test_that("test isResultSuppressed",{
 
   # Test for smaller actual min_cell_count
   expect_warning(isResultSuppressed(result = result, minCellCount = 3))
-
 })
